********************************************************************************
***			 Variables for analysis of final outcomes						 ***
********************************************************************************

drop if treatment==2  | treatment==5 | treatment>=7

* Number of groups
gen num_groups=.
replace num_groups=12 if treatment==1 | treatment==2 | treatment==3 | treatment==4 | treatment==5 | treatment==6 | treatment==8 | treatment==9 | treatment==10 | treatment==11
replace num_groups=11 if treatment==7 | treatment==12
label variable num_groups "Number of groups in treatment"

* Distance between player's ideal-point and final outcome in period
generate dist_opt_result =.
replace dist_opt_result = dist_prop if win==1
replace dist_opt_result = dist_sq if win==0 | win==2
label variable dist_opt_result "Euclidean distance between decision and player's ideal point"

*******************
* Period averages *
*******************

* ONE-period mean final_x and final_y by treatment
by treatment period, sort: egen m1all_fin_x = mean(final_x)
by treatment period, sort: egen m1all_fin_y = mean(final_y)
label variable m1all_fin_x "Mean x-coordinate of decisions per treatment per period"
label variable m1all_fin_y "Mean y-coordinate of decisions per treatment per period"


* Distance of outcomes from mean outcome in treatment per period
generate dev1_mean = ((m1all_fin_x - final_x)^2 + (m1all_fin_y - final_y)^2)^0.5
label variable dev1_mean "Distance between group's decision and mean center of groups's decisions in period"


* Standard distance deviation of final outcomes in treatment per period
generate square_dev1_mean = dev1_mean^2
by treatment period type, sort: egen tot_square_dev1_mean = total(square_dev1_mean)
generate std_m1_final = (tot_square_dev1_mean/(num_groups-2))^0.5
label variable std_m1_final "Standard distance deviation of final outcomes in treatment per period"
drop square_dev1_mean tot_square_dev1_mean

* Mean distance between final outcome and status quo in treatment per period
by treatment period, sort: egen m1all_dist_res_sq = mean(dist_res_sq)
label variable m1all_dist_res_sq "Mean distance between current and previous decision per period"

* Mean distance between final outcome and the core
by treatment period, sort: egen m1_dist_core = mean(dist_core)
label variable m1_dist_core "Mean distance between final outcome and the core in treatment per period"

* Distance of mean final outcome from the core
generate dist_m1mean_core = ((m1all_fin_x - core_x)^2+(m1all_fin_y - core_y)^2)^0.5
label variable dist_m1mean_core "Distance of mean final outcome from the core in treatment per period"

*Standard error of the mean outcome
generate m1_sem = std_m1_final/(sqrt(num_groups))
label variable m1_sem "Standard error of mean outcome in treatment per period"

generate x2_m1_sem = 2*(std_m1_final/(sqrt(num_groups)))
label variable x2_m1_sem "2 Standard errors of mean outcome in treatment per period"

**********************
* 20 period averages *
**********************

* TWENTY-period mean final_x and final_y by group
by groupid, sort: egen m20_fin_x = mean(final_x)
by groupid, sort: egen m20_fin_y = mean(final_y)
label variable m20_fin_x "Mean x-coordinate per group of TWENTY-period mean decisions"
label variable m20_fin_y "Mean y-coordinate per group of TWENTY-period mean decisions"


* TWENTY-period mean final_x and final_y by treatment
by treatment, sort: egen m20all_fin_x = mean(final_x)
by treatment, sort: egen m20all_fin_y = mean(final_y)
label variable m20all_fin_x "Mean x-coordinate per treatment of TWENTY-period mean decisions"
label variable m20all_fin_y "Mean y-coordinate per treatnent of TWENTY-period mean decisions"


* TWENTY-period mean dist_core by group
by groupid, sort: egen m20_dist_core = mean(dist_core)
label variable m20_dist_core "TWENTY-period mean distance of final result to core"


* TWENTY-period phase mean distance of group decision from mean treatment decision
by groupid, sort: egen dev20_mean = mean(dev1_mean)
label variable dev20_mean "TWENTY-period phase average distance group vs treatment mean decision"


* Mean standard distance deviation of period outcomes per treatment over TWENTY-period phases
by treatment, sort: egen std_m20_final = mean(std_m1_final)
label variable std_m20_final "Standard distance deviation of decisions in treatment per TWENTY-period phases"


* TWENTY-period phase mean distance of current from previous group decision
* Without period 1
by groupid, sort: egen dist_res_sq_20_mean = mean(dist_res_sq) if period>1
label variable dist_res_sq_20_mean "TWENTY-period phase mean distance of current from previous group decision"
gsort +subjectid -period
replace dist_res_sq_20_mean = dist_res_sq_20_mean[_n-1] if dist_res_sq_20_mean >= .
gsort +subjectid +period


* VARIANCE OF OUTCOMES WITHIN GROUPS OVER TIME

* Distance of group's decisions in periods from group's mean center decision 
generate dev_group = ((m20_fin_x - final_x)^2 + (m20_fin_y - final_y)^2)^0.5
label variable dev_group "Distance between group's decision in p. and mean center of groups's decisions in all p.s"


* Standard distance deviation of group's decisions in all periods
generate square_dev_group = dev_group^2
by groupid type, sort: egen tot_square_dev_group = total(square_dev_group)
generate std_group_final = (tot_square_dev_group/(num_groups-2))^0.5
label variable std_group_final "Standard distance deviation of group's decisions in all periods"
drop tot_square_dev_group square_dev_group


* Mean standard distance deviation of group decisions in all periods per treatment
by treatment period type, sort: egen mean_std_group_final = mean(std_group_final)
label variable mean_std_group_final "Mean standard distance deviation of group decisions in all periods per treatment"



**********************
* 10 period averages *
**********************

gen per10=.
replace per10=1 if period<=10
replace per10=2 if period>10

gen help_per10=""
replace help_per10="1-10" if period<=10
replace help_per10="11-20" if period>10

gen marker10=0
replace marker10=1 if period==1
replace marker10=1 if period==11

label define avg_10 1 "Periods 1-10" 2 "Periods 11-20"
label values per10 avg_10


* TEN-period mean final_x and final_y by group
by groupid per10, sort: egen m10_fin_x = mean(final_x)
by groupid per10, sort: egen m10_fin_y = mean(final_y)
label variable m10_fin_x "Mean x-coordinate per group of TEN-period mean decisions"
label variable m10_fin_y "Mean y-coordinate per group of TEN-period mean decisions"


* TEN-period mean final_x and final_y by treatment
by treatment per10, sort: egen m10all_fin_x = mean(final_x)
by treatment per10, sort: egen m10all_fin_y = mean(final_y)
label variable m10all_fin_x "Mean x-coordinate per treatment of TEN-period mean decisions"
label variable m10all_fin_y "Mean y-coordinate per treatnent of TEN-period mean decisions"


* TEN-period mean dist_core by group
by groupid per10, sort: egen m10_dist_core = mean(dist_core)
label variable m10_dist_core "TEN-period mean distance of final result to core"


* TEN-period phase mean distance of group decision from mean treatment decision
generate dev10_mean = ((m10all_fin_x - m10_fin_x)^2 + (m10all_fin_y - m10_fin_y)^2)^0.5
label variable dev10_mean "Distance between group's decision and mean center of groups's decisions in period"

* Standard distance deviation of final outcomes in treatment per period
generate square_dev10_mean = dev10_mean^2
by treatment period type, sort: egen tot_square_dev10_mean = total(square_dev10_mean)
generate std_m10_final = (tot_square_dev10_mean/(num_groups-2))^0.5
label variable std_m10_final "Standard distance deviation of 10-period mean final outcomes in treatment"
drop square_dev10_mean tot_square_dev10_mean



* TEN-period phase mean distance of current from previous group decision
* Without period 1
by groupid per10, sort: egen dist_res_sq_10_mean = mean(dist_res_sq) if period>1
label variable dist_res_sq_10_mean "TEN-period phase mean distance of current from previous group decision"
gsort +subjectid -period
replace dist_res_sq_10_mean = dist_res_sq_10_mean[_n-1] if dist_res_sq_10_mean >= .
gsort +subjectid +period


* Distance of 10-period mean final outcome from the core
generate dist_m10mean_core = ((m10all_fin_x - core_x)^2+(m10all_fin_y - core_y)^2)^0.5
label variable dist_m10mean_core "Distance of 10-period mean final outcome from the core in treatment per period"

*Standard error of the mean outcome
generate m10_sem = std_m10_final/(sqrt(num_groups))
label variable m10_sem "Standard error of 10-period mean outcome in treatment"

generate x2_m10_sem = 2*(std_m10_final/(sqrt(num_groups)))
label variable x2_m10_sem "2 Standard errors of 10-period mean outcome in treatment"

****************************
* 5 period phases averages *
****************************

gen per5=.
replace per5=1 if period<=5
replace per5=2 if period>5 & period<=10
replace per5=3 if period>10 & period<=15
replace per5=4 if period>15

gen help_per5=""
replace help_per5="1-5" if period<=5
replace help_per5="6-10" if period>5 & period<=10
replace help_per5="11-15" if period>10 & period<=15
replace help_per5="16-20" if period>15 

gen marker5=0
replace marker5=1 if period==1
replace marker5=1 if period==6
replace marker5=1 if period==11
replace marker5=1 if period==16

label define avg_5 1 "Periods 1-5" 2 "Periods 6-10" 3 "Periods 11-15" 4 "Periods 15-20"
label values per5 avg_5


* FIVE-period mean final_x and final_y by group
by groupid per5, sort: egen m5_fin_x = mean(final_x)
by groupid per5, sort: egen m5_fin_y = mean(final_y)
label variable m5_fin_x "Mean x-coordinate per group of FIVE-period mean decisions"
label variable m5_fin_y "Mean y-coordinate per group of FIVE-period mean decisions"


* FIVE-period mean final_x and final_y by treatment
by treatment per5, sort: egen m5all_fin_x = mean(final_x)
by treatment per5, sort: egen m5all_fin_y = mean(final_y)
label variable m5all_fin_x "Mean x-coordinate per treatment of FIVE-period mean decisions"
label variable m5all_fin_y "Mean y-coordinate per treatnent of FIVE-period mean decisions"




* FIVE-period mean dist_core by group
by groupid per5, sort: egen m5_dist_core = mean(dist_core)
label variable m5_dist_core "FIVE-period mean distance of final result to core"

* FIVE-period phase mean distance of group decision from mean treatment decision
generate dev5_mean = ((m5all_fin_x - m5_fin_x)^2 + (m5all_fin_y - m5_fin_y)^2)^0.5
label variable dev5_mean "FIVE-period phase average distance group vs treatment mean decision"

* Standard distance deviation of final outcomes in treatment per period
generate square_dev5_mean = dev5_mean^2
by treatment period type, sort: egen tot_square_dev5_mean = total(square_dev5_mean)
generate std_m5_final = (tot_square_dev5_mean/(num_groups-2))^0.5
label variable std_m5_final "Standard distance deviation of 5-period mean final outcomes in treatment"
drop square_dev5_mean tot_square_dev5_mean

* Distance of 5-period mean final outcome from the core
generate dist_m5mean_core = ((m5all_fin_x - core_x)^2+(m5all_fin_y - core_y)^2)^0.5
label variable dist_m5mean_core "Distance of 5-period mean final outcome from the core in treatment per period"

*Standard error of the mean outcome
generate m5_sem = std_m5_final/(sqrt(num_groups))
label variable m5_sem "Standard error of 5-period mean outcome in treatment"

generate x2_m5_sem = 2*(std_m5_final/(sqrt(num_groups)))
label variable x2_m5_sem "2 Standard errors of 5-period mean outcome in treatment"


* FIVE-period phase mean distance of current from previous group decision
* Without period 1
by groupid per5, sort: egen dist_res_sq_5_mean = mean(dist_res_sq) if period>1
label variable dist_res_sq_5_mean "FIVE-period phase mean distance of current from previous group decision"
gsort +subjectid -period
replace dist_res_sq_5_mean = dist_res_sq_5_mean[_n-1] if dist_res_sq_5_mean >= .
gsort +subjectid +period



****************************
* 4 period phases averages *
****************************

gen per4=.
replace per4=1 if period<=4
replace per4=2 if period>4 & period<=8
replace per4=3 if period>8 & period<=12
replace per4=4 if period>12 & period<=16
replace per4=5 if period>16

gen help_per4=""
replace help_per4="1-4" if period<=4
replace help_per4="5-8" if period>4 & period<=8
replace help_per4="9-12" if period>8 & period<=12
replace help_per4="13-16" if period>12 & period<=16
replace help_per4="17-20" if period>16 

gen marker4=0
replace marker4=1 if period==1
replace marker4=1 if period==5
replace marker4=1 if period==9
replace marker4=1 if period==13
replace marker4=1 if period==17

label define avg_4 1 "Periods 1-4" 2 "Periods 5-8" 3 "Periods 9-12" 4 "Periods 13-16" 5 "Periods 17-20"
label values per4 avg_4


* FOUR-period mean final_x and final_y by group
by groupid per4, sort: egen m4_fin_x = mean(final_x)
by groupid per4, sort: egen m4_fin_y = mean(final_y)
label variable m4_fin_x "Mean x-coordinate per group of FOUR-period mean decisions"
label variable m4_fin_y "Mean y-coordinate per group of FOUR-period mean decisions"


* FOUR-period mean final_x and final_y by treatment
by treatment per4, sort: egen m4all_fin_x = mean(final_x)
by treatment per4, sort: egen m4all_fin_y = mean(final_y)
label variable m4all_fin_x "Mean x-coordinate per treatment of FOUR-period mean decisions"
label variable m4all_fin_y "Mean y-coordinate per treatnent of FOUR-period mean decisions"


* FIVE-period phase mean distance of group decision from mean treatment decision
generate dev4_mean = ((m4all_fin_x - m4_fin_x)^2 + (m4all_fin_y - m4_fin_y)^2)^0.5
label variable dev4_mean "FOUR-period phase average distance group vs treatment mean decision"

* Standard distance deviation of final outcomes in treatment per period
generate square_dev4_mean = dev4_mean^2
by treatment period type, sort: egen tot_square_dev4_mean = total(square_dev4_mean)
generate std_m4_final = (tot_square_dev4_mean/(num_groups-2))^0.5
label variable std_m4_final "Standard distance deviation of 4-period mean final outcomes in treatment"
drop square_dev4_mean tot_square_dev4_mean

* Distance of 4-period mean final outcome from the core
generate dist_m4mean_core = ((m4all_fin_x - core_x)^2+(m4all_fin_y - core_y)^2)^0.5
label variable dist_m4mean_core "Distance of 4-period mean final outcome from the core in treatment per period"

*Standard error of the mean outcome
generate m4_sem = std_m4_final/(sqrt(num_groups))
label variable m4_sem "Standard error of 4-period mean outcome in treatment"

generate x2_m4_sem = 2*(std_m4_final/(sqrt(num_groups)))
label variable x2_m4_sem "2 Standard errors of 4-period mean outcome in treatment"


* FOUR-period phase mean distance of current from previous group decision
* Without period 1
by groupid per4, sort: egen dist_res_sq_4_mean = mean(dist_res_sq) if period>1
label variable dist_res_sq_4_mean "FOUR-period phase mean distance of current from previous group decision"
gsort +subjectid -period
replace dist_res_sq_4_mean = dist_res_sq_4_mean[_n-1] if dist_res_sq_4_mean >= .
gsort +subjectid +period


********************************
* Does proposal lie in winset? *
********************************

gen prop_winset=2
gen win_a = 0
replace win_a = 1 if points_prop_a > points_sq_a
gen win_b = 0
replace win_b = 1 if points_prop_b > points_sq_b
gen win_c = 0
replace win_c = 1 if points_prop_c > points_sq_c
gen win_d = 0
replace win_d = 1 if points_prop_d > points_sq_d
gen win_e = 0
replace win_e = 1 if points_prop_e > points_sq_e
gen win_all = win_a + win_b + win_c + win_d + win_e

replace prop_winset = 1 if ag_prop_points >= ag_sq_points & win_all>2
replace prop_winset = 0 if ag_prop_points < ag_sq_points | win_all<3
replace prop_winset = -99 if win==2

drop win_a win_b win_c win_d win_e win_all

label variable prop_winset "Does proposal lie in winset of status quo?"
label define winset 1 "yes" 0 "no" -99 "Proposer maintained status quo"
label values prop_winset winset


********************************************************************************
* ROMER ROSENTHAL 
********************************************************************************
	
	gen empty_winset = 0
	replace empty_winset = 1 if (ag_x_opt == sq_x) & (ag_y_opt == sq_y)
	label variable empty_winset "Is winset empty?"
	label values empty_winset lb_yes_no
	
	* Distance between result and optimal proposal
	gen dist_res_ag_opt = ((final_x - ag_x_opt)^2 + (final_y - ag_y_opt)^2)^0.5
	label variable dist_res_ag_opt "Distance between result and optimal proposal of proposer given status quo"
	
	* Distance between AG decision and optimal proposal
	gen dist_dec_ag_opt = ((ag_dec_x - ag_x_opt)^2 + (ag_dec_y - ag_y_opt)^2)^0.5
	label variable dist_dec_ag_opt "Distance between agenda setter decision and optimal proposal of proposer given status quo"
	
	* FIVE-period phase mean distance between AG decision and optimal proposal
		by groupid per5, sort: egen dist_dec_ag_opt_5_mean = mean(dist_dec_ag_opt)
		label variable dist_dec_ag_opt_5_mean "FIVE-period phase mean distance between AG decision and optimal proposal"
		gsort +subjectid -period
		replace dist_dec_ag_opt_5_mean = dist_dec_ag_opt_5_mean[_n-1] if dist_dec_ag_opt_5_mean >= .
		gsort +subjectid +period
	
	
	* Potential gain of agenda setter over SQ
	gen dist_sq_ag_opt = ((sq_x - ag_x_opt)^2 + (sq_y - ag_y_opt)^2)^0.5
	label variable dist_sq_ag_opt "Distance between status quo and optimal proposal of proposer given status quo"

	gen potential_gain_ag = points_ag_opt - ag_sq_points
	label variable potential_gain_ag "Potential gain of agenda setter in comparison to SQ"
	
	* Change in points of agenda setter prop vs. SQ
	gen change_prop_sq = ag_prop_points - ag_sq_points
	replace change_prop_sq = 0 if win==2
	label variable change_prop_sq "Change in earnings of AG, prop vs. SQ"
	
	* Proposal: Realized gain as share of potential gain
	gen realized_gain_ag = (change_prop_sq/potential_gain_ag)*100
	label variable realized_gain_ag "Proposal: Realized gain of AG as percentage share of potential gain"
		* PROBLEM: DU TEILST DURCH NULL WENN WINSET LEER!
		
	* Standard deviation of point distribution for proposal and SQ
	gen stdev_prop =.
	generate avg_points_prop =.
	replace avg_points_prop = (points_prop_a + points_prop_b + points_prop_c + points_prop_d + points_prop_e)/5 if win!=2
	replace stdev_prop = (((points_prop_a - avg_points_prop)^2 + (points_prop_b - avg_points_prop)^2 + (points_prop_c - avg_points_prop)^2 ///
							+ (points_prop_d - avg_points_prop)^2 + (points_prop_e - avg_points_prop)^2)/5)^0.5 if win!=2
	label variable stdev_prop "Standard deviation of point distribution PROPOSAL"
	
	gen stdev_sq =.
	generate avg_points_sq =.
	replace avg_points_sq = (points_sq_a + points_sq_b + points_sq_c + points_sq_d + points_sq_e)/5
	replace stdev_sq = (((points_sq_a - avg_points_sq)^2 + (points_sq_b - avg_points_sq)^2 + (points_sq_c - avg_points_sq)^2 ///
							+ (points_sq_d - avg_points_sq)^2 + (points_sq_e - avg_points_sq)^2)/5)^0.5
	label variable stdev_sq "Standard deviation of point distribution STATUS QUO"
	
	gen prop_more_equal = .
	replace prop_more_equal = 0 if win!=2 & stdev_sq<=stdev_prop
	replace prop_more_equal = 1 if win!=2 & stdev_sq>stdev_prop
	label variable prop_more_equal "Is proposal more equally distributed than SQ?"
	label values prop_more_equal lb_yes_no
	
	gen diff_stdev_sq_prop =.
	replace diff_stdev_sq_prop = stdev_sq - stdev_prop if win!=2
	label variable diff_stdev_sq_prop "Difference standard deviation Status quo and Proposal"
	

	* Payoff of the worst-off subject
		*SQ
		egen pay_worst_sq = rowmin(points_sq_a points_sq_b points_sq_c points_sq_d points_sq_e)
		label variable pay_worst_sq "Lowest individual payoff under SQ"
		
		* Proposal
		egen pay_worst_prop = rowmin(points_prop_a points_prop_b points_prop_c points_prop_d points_prop_e)
		replace pay_worst_prop =. if pay_worst_prop==-99
		label variable pay_worst_prop "Lowest individual payoff under proposal"
		
		* Difference
		generate diff_worst_prop_sq = pay_worst_prop-pay_worst_sq
		replace diff_worst_prop_sq =. if pay_worst_prop==.
		label variable diff_worst_prop_sq "Difference between lowest payoffs under proposal and SQ"
		
		gen worst_prop_higher = .
		replace worst_prop_higher = 0 if win!=2 & pay_worst_prop<=pay_worst_sq
		replace worst_prop_higher = 1 if win!=2 & pay_worst_prop>pay_worst_sq
		label variable worst_prop_higher "Is lowest payoff of proposal higher than lowest payoff SQ?"
		label values worst_prop_higher lb_yes_no
	
	* Payoff of the best-off subject
		*SQ
		egen pay_best_sq = rowmax(points_sq_a points_sq_b points_sq_c points_sq_d points_sq_e)
		label variable pay_best_sq "Highest individual payoff under SQ"
		
		* Proposal
		egen pay_best_prop = rowmax(points_prop_a points_prop_b points_prop_c points_prop_d points_prop_e)
		replace pay_best_prop =. if pay_best_prop==-99
		label variable pay_best_prop "Highest individual payoff under proposal"
		
		* Difference
		generate diff_best_prop_sq = pay_best_prop-pay_best_sq
		replace diff_best_prop_sq =. if pay_best_prop==.
		label variable diff_best_prop_sq "Difference between highest payoffs under proposal and SQ"
	
		gen best_prop_higher = .
		replace best_prop_higher = 0 if win!=2 & pay_best_prop<=pay_best_sq
		replace best_prop_higher = 1 if win!=2 & pay_best_prop>pay_best_sq
		label variable best_prop_higher "Is highest payoff of proposal higher than highest payoff SQ?"
		label values best_prop_higher lb_yes_no
		
	* Range
		generate range_proposal = pay_best_prop - pay_worst_prop
		label variable range_proposal "Range payoffs proposal"
		
		generate range_sq = pay_best_sq - pay_worst_sq
		label variable range_sq "Range payoffs status quo"
		
		generate diff_range_prop_sq = range_proposal - range_sq
		label variable diff_range_prop_sq "Difference between range payoffs proposal and status quo"
		
		
	* Difference between average payoffs under proposal and SQ
		* Measures also efficiency
		generate diff_avg_prop_sq = avg_points_prop - avg_points_sq
		label variable diff_avg_prop_sq "Difference between average payoffs proposal and SQ"
	
		gen avg_prop_higher = .
		replace avg_prop_higher = 0 if win!=2 & avg_points_prop <= avg_points_sq
		replace avg_prop_higher = 1 if win!=2 & avg_points_prop > avg_points_sq
		label variable avg_prop_higher "Is average payoff of proposal higher than highest payoff SQ?"
		label values avg_prop_higher lb_yes_no
		
	* Dummy Maintainance of SQ
	generate ag_maintain_sq = 0
	replace ag_maintain_sq = 1 if win==2
	label variable ag_maintain_sq "Did agendasetter maintain SQß"
	label values ag_maintain_sq lb_yes_no
